@@ -1,6 +1,6 @@
 package PDL::NDBin::Action::Count;
 {
-  $PDL::NDBin::Action::Count::VERSION = '0.010';
+  $PDL::NDBin::Action::Count::VERSION = '0.011';
 }
 # ABSTRACT: Action for PDL::NDBin that counts elements
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use PDL::Lite;		# do not import any functions into this namespace
 use PDL::NDBin::Actions_PP;
-use Params::Validate qw( validate CODEREF SCALAR );
+use Params::Validate qw( validate OBJECT SCALAR );
 
 
 sub new
@@ -17,7 +17,7 @@ sub new
 	my $class = shift;
 	my $self = validate( @_, {
 			N    => { type => SCALAR, regex => qr/^\d+$/ },
-			type => { type => CODEREF, default => \&PDL::long }
+			type => { type => OBJECT, isa => 'PDL::Type', default => PDL::long }
 		} );
 	return bless $self, $class;
 }
@@ -27,7 +27,7 @@ sub process
 {
 	my $self = shift;
 	my $iter = shift;
-	$self->{out} = PDL->zeroes( $self->{type}->(), $self->{N} ) unless defined $self->{out};
+	$self->{out} = PDL->zeroes( $self->{type}, $self->{N} ) unless defined $self->{out};
 	PDL::NDBin::Actions_PP::_icount_loop( $iter->data, $iter->idx, $self->{out}, $self->{N} );
 	# as the plugin processes all bins at once, every variable
 	# needs to be visited only once
@@ -54,7 +54,7 @@ PDL::NDBin::Action::Count - Action for PDL::NDBin that counts elements
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 DESCRIPTION
 
@@ -66,7 +66,7 @@ This class implements an action for PDL::NDBin.
 
 	my $instance = PDL::NDBin::Action::Count->new(
 		N    => $N,
-		type => \&PDL::long,   # default
+		type => long,   # default
 	);
 
 Construct an instance for this action. Requires the number of bins $N as input.
