@@ -1,6 +1,6 @@
 package PDL::NDBin::Action::Sum;
 {
-  $PDL::NDBin::Action::Sum::VERSION = '0.010';
+  $PDL::NDBin::Action::Sum::VERSION = '0.011';
 }
 # ABSTRACT: Action for PDL::NDBin that computes sum
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use PDL::Lite;		# do not import any functions into this namespace
 use PDL::NDBin::Actions_PP;
-use Params::Validate qw( validate CODEREF SCALAR UNDEF );
+use Params::Validate qw( validate OBJECT SCALAR UNDEF );
 
 
 sub new
@@ -17,7 +17,7 @@ sub new
 	my $class = shift;
 	my $self = validate( @_, {
 			N    => { type => SCALAR, regex => qr/^\d+$/ },
-			type => { type => CODEREF | UNDEF, optional => 1 }
+			type => { type => OBJECT | UNDEF, isa => 'PDL::Type', optional => 1 }
 		} );
 	return bless $self, $class;
 }
@@ -28,8 +28,10 @@ sub process
 	my $self = shift;
 	my $iter = shift;
 	if( ! defined $self->{out} ) {
-		my $type = $self->{type} ? $self->{type}->() : undef;
-		$type ||= $iter->data->type < PDL::long() ? PDL::long : $iter->data->type;
+		my $type = $self->{type};
+		if( ! defined $type ) {
+			$type = $iter->data->type < PDL::long() ? PDL::long : $iter->data->type;
+		}
 		$self->{out} = PDL->zeroes( $type, $self->{N} );
 	}
 	$self->{count} = PDL->zeroes( PDL::long, $self->{N} ) unless defined $self->{count};
@@ -60,7 +62,7 @@ PDL::NDBin::Action::Sum - Action for PDL::NDBin that computes sum
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 DESCRIPTION
 
@@ -72,7 +74,7 @@ This class implements an action for PDL::NDBin.
 
 	my $instance = PDL::NDBin::Action::Sum->new(
 		N    => $N,
-		type => \&PDL::double,   # optional
+		type => double,   # optional
 	);
 
 Construct an instance for this action. Requires the number of bins $N as input.
